@@ -2,6 +2,7 @@ import os
 import logging
 import re
 import platform
+import stat
 import sys
 import tempfile
 import zipfile
@@ -103,6 +104,7 @@ class BaseDriver:
         new_target = path / new_name
         try:
             download_file.rename(new_target)
+            os.chmod(new_target, stat.S_IXUSR)
             return str(new_target)
         except FileExistsError:
             download_file.unlink()
